from gtts import gTTS

from pyrogram import Client

from pyrogram.types import Message

async def voice(c: Client, m: Message):    
    Language= "hi"
    name = await client.ask(message.chat.id, text="text_to_speech")
    Text = f"{name.text}"
    speech = gTTS(text = Text , lang = Language, slow = False)
    speech.save("q.mp3")
    await m.reply_audio("q.mp3")



from setuptools import setup, find_packages
import codecs
import os

VERSION = "0.0.3"
DESCRIPTION = "A BASIC VOICE GENERATOR THIS VERSION IS SUPPORTING TELE BOT"


setup(
    name="getvoice",
    version=VERSION,
    author="annoying boy",
    author_email="rppareek091@gmail.com",
    description=DESCRIPTION,
    packages=find_packages(),
    install_require=[],
    keywords=['python'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: Microsoft :: Windows",
    ] 
)